/*
 * Copyright (c) 1998 The University of Bonn
 * All rights reserved.
 * 
 * Permission to use and copy this software in source and binary forms
 * is hereby granted, provided that the above copyright notice, this
 * paragraph and the following disclaimer are retained in any copies
 * of any part of this software and that the University of Bonn is
 * acknowledged in all documentation pertaining to any such copy
 * or derivative work. The name of the University of Bonn may not
 * be used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL 
 * THE UNIVERSITY OF BONN BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF 
 * OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
 * SOFTWARE.
 */
 
#include "connector.h"
#include "adc.h"
#include "salink.h"
#include "rsvp.h"


#ifndef ns_rsvp_link_h
#define ns_rsvp_link_h

/* RSVPLink can be seen as the 'outgoing interface' from a node to
   a link. On RSVPLink, admission control is performed, and reservations
   are set up. */
class RSVPLink : public SALink {
 public:
  RSVPLink();
  /*  void recv(Packet* p, Handler* h);*/
 protected:
  double besteffort_;  /* Remaining bandwidth for best effort traffic */
};


/* RSVPChecker is the 'incoming interface' to a node from a link.
   RSVPChecker listens for RSVP packets and forwards them to the
   RSVP agent (if there is one) on the target node. Note: RSVPChecker
   is installed *after* the delay element on the link (actually after
   the TTLChecker!), RSVPLink *before* it (that is the whole reason 
   why RSVPChecker and RSVPLink can not be one object but have to be 
   split up) */
class RSVPChecker : public Connector {
 public:
  RSVPChecker();
  void give(Packet *p);
  void recv(Packet* p, Handler* h);
 protected:
  nsaddr_t src_;
};

#endif
